jactorch.transforms.vision.functional.image
===========================================

.. automodule:: jactorch.transforms.vision.functional.image

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      crop
      pad
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: crop

.. autofunction:: pad


